==> rgeostat_0.1-1.tar.gz: rgeostat/src/srchnb.f <==
      SUBROUTINE SRCHNB(LON0,LAT0,DO0,INDDO,N0,NDO,LON,LAT,N,NS,
     .                  RSEARCH,NSEARCH,NSMIN,NSMAX,
     .                  INDSRT,INDSNB,INDSNW,DIST)
      
      IMPLICIT NONE
      INTEGER N0,NDO,N,INDSNB(*),INDSNW(*),INDSRT(*),NSEARCH,NSMIN,
     .        NSMAX,NS,INDDO(*)
      DOUBLE PRECISION LAT0(*),LON0(*),LAT(*),LON(*),DIST(*),RSEARCH,
     .                 DO0(*)
c     
c     extract search neigbourhood for points x0 (LON0,LAT0) from
c     x (LON,LAT)
c
      INTEGER I,J,IERR

c     omit points in x0 with do0=0
c      name="do0"
c      call imatpr(do0,n0,1,n0,name,dbglvl)

      I=0
      J=0
      NDO=0
 3000 I=I+1
      IF (DO0(I).EQ.0) GO TO 3001
      J=J+1
      NDO=J
      INDDO(J)=I
 3001 IF (I.LT.N0) GO TO 3000
      
c     no points left!
      IF (NDO.EQ.0) THEN 
         RETURN
      END IF
      
c      name="inddo"
c      call imatpr(inddo,ln0,1,n0,name,dbglvl)

c     determine search neighbourhood
      DO 1 I=1,N
         INDSNW(I)=0
 1    CONTINUE

      DO 5 I=1,NDO
c        determine search neighbourhood for x0_i
c        calculate and sort distances
         CALL DVEC(LON0(INDDO(I)),LAT0(INDDO(I)),LON,LAT,DIST,N)
         CALL DPSORT(DIST,N,INDSRT,1,IERR)
c        handle a fixed search neigbourhood
         IF (NSEARCH.GT.0) THEN      
            IF(NSEARCH.GT.N) NSEARCH=N
            DO 8 J=1,NSEARCH
               INDSNB(J)=INDSRT(J) 
 8          CONTINUE
            DO 9 J=NSEARCH+1,N
               INDSNB(J)=0
 9          CONTINUE
            NS=NSEARCH
         END IF
c        handle a fixed search radius
         IF(NSMAX.LT.0) NSMAX=N
         IF (RSEARCH.GT.0) THEN
            NS=NSMIN
            DO 4 J=1,NSMIN
               INDSNB(J)=INDSRT(J)
 4          CONTINUE
 11         IF (DIST(INDSRT(J)).GT.RSEARCH .OR. J.GT.NSMAX) GO TO 6
            INDSNB(J)=INDSRT(J)
            J=J+1
            GO TO 11
 6          CONTINUE
            NSEARCH=J-1
            NS=NSEARCH
            DO 7 J=J,N
               INDSNB(J)=0
 7          CONTINUE
         END IF
c        store search neigbourhood indices for x0_i in INDSNW, which
c        finally contains the union of all search neigbourhoods
         DO 600 J=1,N
            IF (INDSNB(J).GT.0) INDSNW(INDSNB(J))=INDSNB(J)
 600     CONTINUE
 5    CONTINUE

c     now INDSNW contains indices of the superset of all neigbourhoods.
c     strip now all "0"s from INDSNW and copy the indices back to INDSNB 
      I=1
      J=1
 700  IF (INDSNW(I).EQ.0) THEN
         I=I+1
      ELSE
         INDSNB(J)=INDSNW(I)
         I=I+1
         J=J+1
      END IF
      IF (I.LE.N) GO TO 700
         
      RETURN
      END

==> rgeostat_0.1-3.tar.gz: rgeostat/src/srchnb.f <==
      SUBROUTINE SRCHNB(LON0,LAT0,DO0,INDDO,N0,NDO,LON,LAT,N,NS,
     .                  RSEARCH,NSEARCH,NSMIN,NSMAX,
     .                  INDSRT,INDSNB,INDSNW,DIST)
      
      IMPLICIT NONE
      INTEGER N0,NDO,N,INDSNB(*),INDSNW(*),INDSRT(*),NSEARCH,NSMIN,
     .        NSMAX,NS,INDDO(*),DO0(*)
      DOUBLE PRECISION LAT0(*),LON0(*),LAT(*),LON(*),DIST(*),RSEARCH
c     
c     extract search neigbourhood for points x0 (LON0,LAT0) from
c     x (LON,LAT)
c
      INTEGER I,J,IERR

c     determine search neighbourhood
      DO 1 I=1,N
         INDSNW(I)=0
 1    CONTINUE

      DO 5 I=1,NDO
c        determine search neighbourhood for x0_i
c        calculate and sort distances
         CALL DVEC(LON0(INDDO(I)),LAT0(INDDO(I)),LON,LAT,DIST,N)
         CALL DPSORT(DIST,N,INDSRT,1,IERR)
         DO 111 J=1,N
            INDSNB(J)=0
 111     CONTINUE
c        handle a fixed search neigbourhood
         IF (NSEARCH.GT.0) THEN      
            IF(NSEARCH.GT.N) NSEARCH=N
            DO 8 J=1,NSEARCH
               INDSNB(J)=INDSRT(J) 
 8          CONTINUE
            NS=NSEARCH
         END IF
c        handle a fixed search radius
         IF (RSEARCH.GT.0) THEN
            DO 4 J=1,NSMIN
               INDSNB(J)=INDSRT(J)
 4          CONTINUE
 11         IF (DIST(INDSRT(J)).GT.RSEARCH .OR. J.GT.NSMAX) GO TO 6
            INDSNB(J)=INDSRT(J)
            J=J+1
            GO TO 11
 6          CONTINUE
         END IF
c        store search neigbourhood indices for x0_i in INDSNW, which
c        finally contains the union of all search neigbourhoods
         DO 600 J=1,N
            IF (INDSNB(J).GT.0) INDSNW(INDSNB(J))=INDSNB(J)
 600     CONTINUE
 5    CONTINUE

c     now INDSNW contains indices of the superset of all neigbourhoods.
c     strip now all "0"s from INDSNW and copy the indices back to INDSNB 
      I=1
      J=1
 700  IF (INDSNW(I).EQ.0) THEN
         I=I+1
      ELSE
         INDSNB(J)=INDSNW(I)
         I=I+1
         J=J+1
      END IF
      IF (I.LE.N) GO TO 700

      NS=J-1
      IF (NS.LT.N) THEN
         DO 701 I=NS+1,N
            INDSNB(I)=0
 701     CONTINUE
      END IF

      RETURN
      END
